@@ -6,12 +6,13 @@ import sys
 from collections import OrderedDict
 from copy import deepcopy
 from io import IOBase
+from itertools import chain
 from subprocess import getstatusoutput
 from traceback import format_exception
 from types import TracebackType
 from typing import (
-    Any, Dict, Iterable, List, Optional, Pattern, Set, Tuple,
-    Union
+    Any, Collection, Container, Dict, Iterable, List, Optional, Pattern, Set,
+    Tuple, Union
 )
 from warnings import warn
 
@@ -693,7 +694,9 @@ def get_package_version(package_name: str) -> str:
     return version
 
 
-def _get_freeze_source_packages() -> Dict[str, str]:
+def _get_freeze_source_packages(
+    exclude: Container[str] = ()
+) -> Dict[str, str]:
     """
     Get a dictionary of package names mapped to a version requirement
     identifier for packages found in the root of a `sys.path` directory
@@ -706,11 +709,31 @@ def _get_freeze_source_packages() -> Dict[str, str]:
     ):
         source_package_name = source_package_name.replace('_', '-')
         package_version = f'{source_package_name}=={version}'
-        source_package_names[source_package_name] = package_version
+        if source_package_name not in exclude:
+            source_package_names[source_package_name] = package_version
     return source_package_names
 
 
-def get_freeze(editable: bool = False) -> Iterable[str]:
+def get_package_requirements(package_name: str) -> Iterable[str]:
+    # Get the output of `pip show`
+    status: int
+    output: str
+    line: str
+    status, output = getstatusoutput(
+        f'{sys.executable} -m pip show {package_name}'
+    )
+    for line in output.split('\n'):
+        if line.startswith('Requires:'):
+            required_package_name: str
+            for required_package_name in line.lstrip().split(','):
+                yield required_package_name.strip().replace('_', '-')
+            break
+
+
+def get_freeze(
+    editable: bool = False,
+    exclude: Union[str, Collection[str]] = ()
+) -> Iterable[str]:
     """
     Iterate over the packages installed/referenced in the current environment.
 
@@ -720,6 +743,26 @@ def get_freeze(editable: bool = False) -> Iterable[str]:
       will be returned as a package name + version identifier rather than
       an editable requirement referencing a VCS.
     """
+    package_version: str
+    package_name: str
+    source_package_names: Dict[str, str] = _get_freeze_source_packages(
+        exclude=exclude
+    )
+    # Normalize excluded package names and expand to include packages
+    # required by the excluded package
+    exclude = set(chain(
+        (normalized_package_name,) +
+        tuple(get_package_requirements(normalized_package_name))
+        for normalized_package_name in (
+            package_name.replace('_', '-')
+            for package_name in (
+                (exclude,)
+                if isinstance(exclude, str) else
+                exclude
+            )
+        )
+    ))
+    # Get the output of `pip freeze`
     status: int
     output: str
     status, output = getstatusoutput(
@@ -727,10 +770,7 @@ def get_freeze(editable: bool = False) -> Iterable[str]:
     )
     if status:
         raise OSError(output)
-    source_package_names: Dict[str, str] = _get_freeze_source_packages()
     # Get all installed packages
-    package_version: str
-    package_name: str
     for package_version in output.split('\n'):
         is_editable_requirement: bool = (
             package_version.startswith('-e ')
@@ -753,13 +793,14 @@ def get_freeze(editable: bool = False) -> Iterable[str]:
                 f'{package_name}=='
                 f'{get_package_version(package_name)}'
             )
-        # Make sure the package wasn't among the source packages already
-        # yielded
-        if package_name in source_package_names:
-            if editable:
+        if package_name not in exclude:
+            # Make sure the package wasn't among the source packages already
+            # yielded
+            if package_name in source_package_names:
+                if editable:
+                    yield package_version
+                    del source_package_names[package_name]
+            else:
                 yield package_version
-                del source_package_names[package_name]
-        else:
-            yield package_version
     for package_version in source_package_names.values():
         yield package_version
